==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/ALERTGRIDDATAID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ALERTGRIDDATAID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ALERTGRIDDATAID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALERTGRIDDATAPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALERTGRIDDATAID_Type", propOrder = {
    "alertgriddatapk"
})
public class ALERTGRIDDATAID_Type {

    @XmlElement(name = "ALERTGRIDDATAPK", required = true)
    protected String alertgriddatapk;

    /**
     * Obtient la valeur de la propriété alertgriddatapk.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALERTGRIDDATAPK() {
        return alertgriddatapk;
    }

    /**
     * Définit la valeur de la propriété alertgriddatapk.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALERTGRIDDATAPK(String value) {
        this.alertgriddatapk = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/ALERTGRIDDATAID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ALERTGRIDDATAID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ALERTGRIDDATAID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALERTGRIDDATAPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALERTGRIDDATAID_Type", propOrder = {
    "alertgriddatapk"
})
public class ALERTGRIDDATAID_Type {

    @XmlElement(name = "ALERTGRIDDATAPK", required = true)
    protected String alertgriddatapk;

    /**
     * Gets the value of the alertgriddatapk property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALERTGRIDDATAPK() {
        return alertgriddatapk;
    }

    /**
     * Sets the value of the alertgriddatapk property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALERTGRIDDATAPK(String value) {
        this.alertgriddatapk = value;
    }

}
